@@ -4,42 +4,33 @@ calibrator.py
 Module for the calibrator functionality.
 """
 
+from configparser import ConfigParser
+from os.path import join
+from pathlib import Path
+
 import numpy as np
 import pandas as pd
-from configparser import ConfigParser
-from pathlib import Path
 from tqdm import tqdm
-from os.path import join
-from .external_instrument_model import ExternalInstrumentModel
+
 from gaiaxpy.config.paths import config_path
 from gaiaxpy.core.config import _load_xpmerge_from_csv, _load_xpsampling_from_csv
-from gaiaxpy.core.generic_functions import cast_output, _get_spectra_type, \
-                                           _validate_arguments, \
-                                           _validate_wl_sampling
-from gaiaxpy.core.satellite import BANDS, BP_WL, RP_WL
+from gaiaxpy.core.generic_functions import cast_output, _get_spectra_type, _validate_arguments, _validate_wl_sampling
 from gaiaxpy.core.generic_variables import pbar_colour, pbar_units
+from gaiaxpy.core.satellite import BANDS, BP_WL, RP_WL
 from gaiaxpy.input_reader.input_reader import InputReader
 from gaiaxpy.output.sampled_spectra_data import SampledSpectraData
 from gaiaxpy.spectrum.absolute_sampled_spectrum import AbsoluteSampledSpectrum
 from gaiaxpy.spectrum.sampled_basis_functions import SampledBasisFunctions
 from gaiaxpy.spectrum.utils import _get_covariance_matrix
 from gaiaxpy.spectrum.xp_continuous_spectrum import XpContinuousSpectrum
+from .external_instrument_model import ExternalInstrumentModel
 
-config_parser = ConfigParser()
-config_parser.read(join(config_path, 'config.ini'))
-tqdm.pandas(desc='Processing data', unit=pbar_units['calibrator'], leave=False, \
-            colour=pbar_colour) # Activate tqdm for pandas
+# Activate tqdm for pandas
+tqdm.pandas(desc='Processing data', unit=pbar_units['calibrator'], leave=False, colour=pbar_colour)
 
-def calibrate(
-        input_object,
-        sampling=None,
-        truncation=False,
-        output_path='.',
-        output_file='output_spectra',
-        output_format=None,
-        save_file=True,
-        username=None,
-        password=None):
+
+def calibrate(input_object, sampling=None, truncation=False, output_path='.', output_file='output_spectra',
+              output_format=None, save_file=True, username=None, password=None):
     """
     Calibration utility: calibrates the input internally-calibrated
     continuously-represented mean spectra to the absolute system. An absolute
@@ -73,30 +64,12 @@ def calibrate(
             ndarray: The sampling used to calibrate the input spectra (user-provided or default).
     """
     # Call internal method
-    return _calibrate(
-        input_object,
-        sampling,
-        truncation,
-        output_path,
-        output_file,
-        output_format,
-        save_file,
-        username=username,
-        password=password)
+    return _calibrate(input_object, sampling, truncation, output_path, output_file, output_format, save_file,
+                      username=username, password=password)
 
 
-def _calibrate(
-        input_object,
-        sampling=None,
-        truncation=False,
-        output_path='.',
-        output_file='output_spectra',
-        output_format=None,
-        save_file=True,
-        bp_model='v375wi',
-        rp_model='v142r',
-        username=None,
-        password=None):
+def _calibrate(input_object, sampling=None, truncation=False, output_path='.', output_file='output_spectra',
+               output_format=None, save_file=True, bp_model='v375wi', rp_model='v142r', username=None, password=None):
     """
     Internal method of the calibration utility. Refer to "calibrate".
 
@@ -113,14 +86,11 @@ def _calibrate(
     """
     _validate_wl_sampling(sampling)
     _validate_arguments(_calibrate.__defaults__[3], output_file, save_file)
-    parsed_input_data, extension = InputReader(input_object, _calibrate, \
-                                               username, password)._read()
+    parsed_input_data, extension = InputReader(input_object, _calibrate, username, password)._read()
     label = 'calibrator'
-    xp_design_matrices, xp_merge = _generate_xp_matrices_and_merge(label, \
-                                   sampling, bp_model, rp_model)
+    xp_design_matrices, xp_merge = _generate_xp_matrices_and_merge(label, sampling, bp_model, rp_model)
     # Create sampled basis functions
-    spectra_df, positions = _create_spectra(parsed_input_data, truncation, \
-                                            xp_design_matrices, xp_merge)
+    spectra_df, positions = _create_spectra(parsed_input_data, truncation, xp_design_matrices, xp_merge)
     output_data = SampledSpectraData(spectra_df, positions)
     output_data.data = cast_output(output_data)
     # Save output
@@ -144,11 +114,11 @@ def _create_merge(xp, sampling):
     wl_low = RP_WL.low
 
     if xp == BANDS.bp:
-        weight = np.array([1.0 if wl < wl_low else 0.0 if wl > wl_high else (
-            1.0 - (wl - wl_low) / (wl_high - wl_low)) for wl in sampling])
+        weight = np.array([1.0 if wl < wl_low else 0.0 if wl > wl_high else (1.0 - (wl - wl_low) / (wl_high - wl_low))
+                           for wl in sampling])
     elif xp == BANDS.rp:
-        weight = np.array([0.0 if wl < wl_low else 1.0 if wl > wl_high else (
-            wl - wl_low) / (wl_high - wl_low) for wl in sampling])
+        weight = np.array([0.0 if wl < wl_low else 1.0 if wl > wl_high else (wl - wl_low) / (wl_high - wl_low) for wl
+                           in sampling])
     else:
         raise ValueError(f'Given band is {xp}, but should be either bp or rp.')
     return weight
@@ -158,39 +128,40 @@ def _generate_xp_matrices_and_merge(label, sampling, bp_model, rp_model):
     """
     Get xp_design_matrices and xp_merge.
     """
-    def _get_file_for_xp(xp, key, bp_model=bp_model, rp_model=rp_model):
+
+    def _get_file_for_xp(_xp, key, _bp_model=bp_model, _rp_model=rp_model):
+        config_parser = ConfigParser()
+        config_parser.read(join(config_path, 'config.ini'))
         file_name = config_parser.get(label, key)
-        if xp == BANDS.bp:
-            model = bp_model
-        elif xp == BANDS.rp:
-            model = rp_model
-        return join(config_path, f"{file_name.replace('xp', xp).replace('model', model)}".format(key))
+        if _xp == BANDS.bp:
+            model = _bp_model
+        elif _xp == BANDS.rp:
+            model = _rp_model
+        else:
+            raise ValueError('Band must be either bp or rp.')
+        return join(config_path, f"{file_name.replace('xp', _xp).replace('model', model)}")
 
     xp_design_matrices = {}
     if sampling is None:
         xp_sampling_grid, xp_merge = _load_xpmerge_from_csv(label, bp_model=bp_model)
         xp_design_matrices = _load_xpsampling_from_csv(label, bp_model=bp_model)
         for xp in BANDS:
-            xp_design_matrices[xp] = SampledBasisFunctions.from_design_matrix(
-                xp_sampling_grid, xp_design_matrices[xp])
+            xp_design_matrices[xp] = SampledBasisFunctions.from_design_matrix(xp_sampling_grid, xp_design_matrices[xp])
     else:
         xp_merge = {}
         for xp in BANDS:
-            instr_model = ExternalInstrumentModel.from_config_csv(
-                _get_file_for_xp(
-                    xp, 'dispersion'), _get_file_for_xp(
-                    xp, 'response'), _get_file_for_xp(
-                    xp, 'bases'))
+            instr_model = ExternalInstrumentModel.from_config_csv(_get_file_for_xp(xp, 'dispersion'),
+                                                                  _get_file_for_xp(xp, 'response'),
+                                                                  _get_file_for_xp(xp, 'bases'))
             xp_merge[xp] = _create_merge(xp, sampling)
-            xp_design_matrices[xp] = SampledBasisFunctions.from_external_instrument_model(
-                sampling, xp_merge[xp], instr_model)
+            xp_design_matrices[xp] = SampledBasisFunctions.from_external_instrument_model(sampling, xp_merge[xp],
+                                                                                          instr_model)
     return xp_design_matrices, xp_merge
 
 
 def _create_spectra(parsed_spectrum_file, truncation, design_matrices, merge):
-    nrows = len(parsed_spectrum_file)
-    spectra_series = parsed_spectrum_file.progress_apply(lambda row: \
-                 _create_spectrum(row, truncation, design_matrices, merge), axis=1)
+    spectra_series = parsed_spectrum_file.progress_apply(lambda row: _create_spectrum(row, truncation, design_matrices,
+                                                                                      merge), axis=1)
     positions = spectra_series.iloc[0]._get_positions()
     spectra_type = _get_spectra_type(spectra_series.iloc[0])
     spectra_series = spectra_series.map(lambda x: x._spectrum_to_dict())
@@ -220,25 +191,18 @@ def _create_spectrum(row, truncation, design_matrix, merge):
     """
     source_id = row['source_id']
     cont_dict = {}
+    recommended_truncation = {}
     # Split both bands
     for band in BANDS:
         try:
             covariance_matrix = _get_covariance_matrix(row, band)
             if covariance_matrix is not None:
-                continuous_object = XpContinuousSpectrum(
-                    source_id,
-                    band,
-                    row[f'{band}_coefficients'],
-                    covariance_matrix,
-                    row[f'{band}_standard_deviation'])
+                continuous_object = XpContinuousSpectrum(source_id, band, row[f'{band}_coefficients'],
+                                                         covariance_matrix, row[f'{band}_standard_deviation'])
                 cont_dict[band] = continuous_object
             if truncation:
-                recommended_truncation = row[f'{band}_n_relevant_bases']
-            else:
-                recommended_truncation = -1
+                recommended_truncation[band] = row[f'{band}_n_relevant_bases']
         except Exception:
             # If the band is not present, ignore it
             continue
-    return AbsoluteSampledSpectrum(
-        source_id, cont_dict, design_matrix, merge,
-        truncation=recommended_truncation)
+    return AbsoluteSampledSpectrum(source_id, cont_dict, design_matrix, merge, truncation=recommended_truncation)
